@@ -130,7 +130,7 @@ class Client:
         else:
             raise exceptions.CakeworkError("Internal server exception") 
     
-    def run(self, project, task, params, compute):
+    def run(self, project, task, params, compute ={"cpu":1, "memory": 256}):
         sanitized_task = task.lower()
         sanitized_task = task.replace('_', '-')
 
@@ -157,37 +157,4 @@ class Client:
         response = requests.post(f"{self.frontend_url}/client/projects/{project}/tasks/{sanitized_task}/runs", json=request, headers=self.headers)
         response_json = response.json()
         run_id = response_json["runId"] # this may be null?
-        return run_id
-
-    def __getattr__(self, name):
-        def method(*args, compute={}):            
-            sanitized_name = name.lower()
-            sanitized_name = name.replace('_', '-')
-
-            parameters = json.dumps(args)
-            request = {
-                "parameters": parameters
-            }
-
-            cpu = compute.get("cpu")
-            if cpu is not None:
-                if cpu < 1 or cpu > 8:
-                    raise exceptions.CakeworkError("Number of cpus must be between 1 and 8")
-                else:
-                    request["cpu"] = cpu
-                    
-            memory = compute.get("memory")
-            if memory is not None:
-                if memory < 256 or memory > 16384:
-                    raise exceptions.CakeworkError("Amount of memory must be between 256 and 16384 mb")
-                else:
-                    request["memory"] = memory
-        
-            # print(request) # TODO delete
-  
-            response = requests.post(f"{self.frontend_url}/client/projects/{self.project}/tasks/{sanitized_name}/runs", json=request, headers=self.headers)
-            response_json = response.json()
-            run_id = response_json["runId"] # this may be null?
-            return run_id
-
-        return method
\ No newline at end of file
+        return run_id
\ No newline at end of file
